##############################################################################
#
#    Copyright (C) 2004-2010 Yannick Soldati. All Rights Reserved
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from osv import osv
from osv import fields


class res_partner_title(osv.osv):
    _inherit = 'res.partner.title'

    _columns = {
        'shortcut': fields.char('Shortcut', required=True, size=16,
                translate=True),
    }
res_partner_title()


class res_partner(osv.osv):
    _inherit = 'res.partner'

    _columns = {
        'phone': fields.related('address','phone', type='char',
                relation='res.partner.address', string='Phone'),
        'email': fields.related('address','email', type='char',
                relation='res.partner.address', string='Email'),
        'mobile': fields.related('address','mobile', type='char',
                relation='res.partner.address', string='Mobile'),

    }
res_partner()


class res_partner_address(osv.osv):
    _inherit = 'res.partner.address'

    def name_get(self, cr, user, ids, context=None):
        if context is None:
            context = {}

        if not len(ids):
            return []
        res = []
        for r in self.read(cr, user, ids, ['name', 'zip', 'city',
                'partner_id', 'street']):
            if context.get('contact_display', 'contact')=='partner':
                res.append((r['id'], r['partner_id'][1]))
            else:
                addr = r['name'] or ''
                if r['name'] and (r['zip'] or r['city']):
                    addr += ', '
                addr += (r['street'] or '') + ', ' + \
                    (r['zip'] or '') + ' ' + (r['city'] or '')
                res.append((r['id'], addr.strip() or '/'))
        return res

res_partner_address()


class crm_case(osv.osv):
    _inherit = 'crm.case'

    _columns = {
        'priority': fields.selection((('5','Lowest'),
            ('4','Low'),
            ('3','Normal'),
            ('2','High'),
            ('1','Highest')), 'Priority', select=2),
        'stage_id': fields.many2one ('crm.case.stage', 'Stage',
                domain="[('section_id','=',section_id)]", select=1),
    }

    def onchange_partner_address_id(self, cr, uid, ids, part, email=False):
        if not part:
            return {'value':{}}
        data = {}

        partner_address_obj = self.pool.get('res.partner.address')
        partner_address = partner_address_obj.browse(cr, uid, part)

        if not email:
            data['email_from'] = partner_address.email

        data['partner_phone'] = partner_address.phone
        data['partner_mobile'] = partner_address.mobile

        return {'value':data}

    _order = 'id desc'

crm_case()
